<?php
/*
 * Copyright (c) 2013, webvariants GbR, http://www.webvariants.de
 *
 * This file is released under the terms of the MIT license. You can find the
 * complete text in the attached LICENSE file or online at:
 *
 * http://www.opensource.org/licenses/mit-license.php
 */

/**
 * Datentyp "Mehrfach-Eingabe"
 *
 * @ingroup datatypes
 */
class WV_Datatype_Multi extends WV_Datatype_Base implements WV_IDatatype {
	public function renderForm(sly_Form $form, WV_IProperty $property, $value) {
		$params    = $property->getParams();
		$propID    = $property->getID();
		$title     = $property->getTitle();
		$name      = 'property_'.$propID.'_value';
		$value     = $this->decodeFormValue($property, $value);
		$value     = json_decode($value, true);
		$params    = $this->deserializeParams($params);
		$multi     = new WV_Form_Multiple($name, $title, $property->getType(), $property->getName());
		$fake_form = new WV_Datatype_Multi_FakeForm($multi);

		if (empty($value)) {
			$value = array();
		}

		foreach ($params['children'] as $childName => $child) {
			$property2 = new _WV2_Info($property->getType(), $name.'_'.$childName, array(
				'title'    => $child['title'],
				'datatype' => $child['datatype'],
				'params'   => array_key_exists('params', $child) ? $child['params'] : array(),
				'backend'  => array_key_exists('backend', $child) ? $child['backend'] : true
			));

			$multi->setLabelAttr(array_key_exists('label_attr', $child) ? $child['label_attr'] : null);
			$multi->setLabelStyle(array_key_exists('label_style', $child) ? $child['label_style'] : null);
			$multi->setNewline(array_key_exists('newline', $child) ? $child['newline'] : null);

			if (!$property2->getBackend()) {
				$multi->hideStart();
			}

			$datatype = WV_Datatype::factory($child['datatype']);
			$datatype->renderForm($fake_form, $property2, array(array_key_exists($childName, $value) ? $value[$childName] : ''));
		}

		$form->add($multi);

		return $form;
	}

	protected function getDefaultParams() {
		return array('children' => array());
	}

	public function serializeValue($values, array $params) {
		if (!is_array($values)) {
			$values = array();
		}

		$ret = array();

		foreach ($params['children'] as $childName => $child) {
			$value    = array_key_exists($childName, $values) ? $values[$childName] : null;
			$datatype = WV_Datatype::factory($child['datatype']);

			$ret[$childName] = $datatype->serializeValue($value, array_key_exists('params', $child) ? $child['params'] : array());
		}

		return json_encode($ret);
	}

	public function deserializeValue($value, array $params) {
		$values = json_decode($value, true);

		if (!is_array($values)) {
			$values = array();
		}

		foreach ($params['children'] as $childName => $child) {
			$value    = array_key_exists($childName, $values) ? $values[$childName] : '';
			$datatype = WV_Datatype::factory($child['datatype']);

			$ret[$childName] = $datatype->deserializeValue($value, array_key_exists('params', $child) ? $child['params'] : array());
		}

		return $ret;
	}

	public function isValueContained($valueToSearch, $valueFromDatabase, array $params, $operator) {
		throw new WV_Exception_Datatype('not yet implemented');
	}

	public function serializeFormFilter($list, WV_IProperty $property) {
		$params = $property->getParams();
		$propID = $property->getID();
		$name   = 'property_'.$propID.'_value';

		foreach ($list as $clangID => $values) {
			$values = array_values(sly_makeArray($values));
			$data   = array();

			foreach ($params['children'] as $childName => $child) {
				$property2 = new _WV2_Info($property->getType(), $name.'_'.$childName, array(
					'title'    => $child['title'],
					'datatype' => $child['datatype'],
					'params'   => array_key_exists('params', $child) ? $child['params'] : array(),
					'backend'  => array_key_exists('backend', $child) ? $child['backend'] : true
				));

				$datatype = WV_Datatype::factory($child['datatype']);
				$data[$childName] = $datatype->serializeForm($property2);
			}

			$list[$clangID] = json_encode($data);
		}

		return $list;
	}

	public function getDefaultValue(WV_IProperty $property) {
		$default_value = array();
		$params        = $property->getParams();

		foreach ($params['children'] as $childName => $child) {
			$default_value[$childName] = isset($child['default']) ? $child['default'] : null;
		}

		return $this->serializeValue(array($default_value), $property->getParams());
	}
}
