<?php
/*
 * Copyright (c) 2013, webvariants GbR, http://www.webvariants.de
 *
 * This file is released under the terms of the MIT license. You can find the
 * complete text in the attached LICENSE file or online at:
 *
 * http://www.opensource.org/licenses/mit-license.php
 */

namespace wv\metainfo\Listener;

use wv\metainfo\Metainfo;
use wv\metainfo\Exception;

class Model {
	/**
	 * Provide additional getters for models
	 *
	 * $modelArticle->getMeta($metainfo[, $default[, $clang]]);
	 * $modelCategory->getMeta($metainfo[, $default[, $clang]]);
	 * $modelMedium->getMeta($metainfo[, $default[, $clang]]);
	 * $modelUser->getMeta($metainfo[, $default[, $clang]]);
	 *
	 * @return mixed
	 */
	public function getObjectMeta($subject, array $params) {
		$args = $params['arguments'];

		if (count($args) < 1) {
			throw new Exception('Too few arguments for getMeta().');
		}

		$obj      = $params['object'];
		$objectId = $obj->getId();
		$type     = Metainfo::getTypeForObject($obj);
		$revision = $obj->getRevision();
		$info     = $args[0];
		$default  = isset($args[1]) ? $args[1] : null;
		$clang    = isset($args[2]) ? (int) $args[2] : $this->getClang($type, $obj);
		$raw      = isset($args[3]) ? (bool) $args[3] : null;

		$values = Metainfo::objectData($objectId, $info, array(), $clang, $revision, $type, $raw);

		return $values[$info] !== null ? $values[$info] : $default;
	}

	/**
	 * Provide additional getters for models
	 *
	 * $modelArticle->getAllMetaData([$clang]]);
	 * $modelCategory->getAllMetaData([$clang]]);
	 * $modelMedium->getAllMetaData([$clang]]);
	 * $modelUser->getAllMetaData([$clang]]);
	 *
	 * @return array
	 */
	public function getAllObjectMetaData($subject, array $params) {
		// check call
		$args     = $params['arguments'];
		$obj      = $params['object'];
		$type     = Metainfo::getTypeForObject($obj);
		$objectId = $obj->getId();
		$clang    = isset($args[0]) ? (int) $args[0] : $this->getClang($type, $obj);
		$revision = $obj->getRevision();
		$raw      = isset($args[3]) ? (bool) $args[3] : null;

		return Metainfo::objectData($objectId, null, array(), $clang, $revision, $type, $raw);
	}

	protected function getClang($type, $obj) {
		return ($type !== Metainfo::TYPE_MEDIUM && $type !== Metainfo::TYPE_USER) ? $obj->getClang() : \sly_Core::getCurrentClang();
	}
}
